@@ -6,7 +6,7 @@ use warnings;
 use Module::Build;
 our @ISA = qw{ Module::Build };
 
-our $VERSION = '0.042';
+our $VERSION = '0.043';
 
 use Carp;
 
@@ -91,7 +91,8 @@ C<--test_files> argument.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org/>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Astro-SIMBAD-Client/issues/>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -99,7 +100,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
