@@ -39,7 +39,7 @@ sub meta_merge {
 	},
 	resources => {
 	    bugtracker	=> {
-		web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-SIMBAD-Client',
+		web	=> 'https://github.com/trwyant/perl-Astro-SIMBAD-Client/issues',
 #                mailto  => 'wyant@cpan.org',
             },
 	    license	=> 'http://dev.perl.org/licenses/',
@@ -195,7 +195,8 @@ information makes it into F<META.yml>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org/>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Astro-SIMBAD-Client/issues/>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -203,7 +204,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2020 by Thomas R. Wyant, III
+Copyright (C) 2010-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
